@@ -1,12 +1,13 @@
-use crate::{
-    bundle, canonical, crc, dtntime, eid, flags::BlockControlFlags, primary, Bundle, ByteBuffer,
-};
+#[cfg(feature = "instant")]
+use crate::ByteBuffer;
+use crate::{bundle, canonical, crc, dtntime, eid, flags::BlockControlFlags, primary, Bundle};
+
 use core::num::ParseIntError;
-use instant::Instant;
 use nanorand::{Rng, WyRand};
+#[cfg(feature = "instant")]
 use std::convert::TryFrom;
-use std::io::stdout;
-use std::io::Write;
+#[cfg(feature = "instant")]
+use std::io::{stdout, Write};
 use std::time::{SystemTime, UNIX_EPOCH};
 
 #[cfg(not(target_arch = "wasm32"))]
@@ -142,7 +143,10 @@ pub fn get_bench_bundle(crc_type: crc::CrcRawType) -> Bundle {
     b.validate().unwrap();
     b
 }
+#[cfg(feature = "instant")]
+use instant::Instant;
 
+#[cfg(feature = "instant")]
 pub fn bench_bundle_create(runs: i64, crc_type: crc::CrcRawType) -> Vec<ByteBuffer> {
     let crc_str = match crc_type {
         crc::CRC_NO => "CRC_NO",
@@ -169,6 +173,7 @@ pub fn bench_bundle_create(runs: i64, crc_type: crc::CrcRawType) -> Vec<ByteBuff
     bundles
 }
 
+#[cfg(feature = "instant")]
 pub fn bench_bundle_encode(runs: i64, crc_type: crc::CrcRawType) -> Vec<ByteBuffer> {
     let crc_str = match crc_type {
         crc::CRC_NO => "CRC_NO",
@@ -198,6 +203,7 @@ pub fn bench_bundle_encode(runs: i64, crc_type: crc::CrcRawType) -> Vec<ByteBuff
     bundles
 }
 
+#[cfg(feature = "instant")]
 pub fn bench_bundle_load(runs: i64, crc_type: crc::CrcRawType, mut bundles: Vec<ByteBuffer>) {
     let crc_str = match crc_type {
         crc::CRC_NO => "CRC_NO",
